[−][src]Enum rouille::input::post::PostError
Error that can happen when decoding POST data.
Variants
The Content-Type header of the request indicates that it doesn't contain POST data.
Can't parse the body of the request because it was already extracted.
IoError(IoError)Could not read the body from the request.
NotUtf8(String)Failed to parse a string field.
There was an error with a particular field.
Fields of Field
field: Cow<'static, str>error: PostFieldErrorTrait Implementations
impl Debug for PostError[src]
impl Display for PostError[src]
impl Error for PostError[src]
fn description(&self) -> &str[src]
fn cause(&self) -> Option<&dyn Error>[src]
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn backtrace(&self) -> Option<&Backtrace>[src]
impl From<Error> for PostError[src]